@@ -597,8 +597,9 @@ sub twigMzxml_readCmpd{
   my $tmp=$elPeaks->text;
   my ($moz, $int)=twigMzxml_decodeMzXmlPeaks($tmp);
   my $n=(scalar @$moz)-1;
-  $cmpd->addOnePeak([$moz->[0], $int->[0]]);
+#  $cmpd->addOnePeak([$moz->[0], $int->[0]]);
    for (0..$n) {
+     warn "[$moz->[$_], $int->[$_]]";
      $cmpd->addOnePeak([$moz->[$_], $int->[$_]]);
    }
 
@@ -627,6 +628,7 @@ sub twigMzxml_decodeMzXmlPeaks{
     }
     $isMz=1-$isMz;
   }
+  warn "m=@m\n";
   return (\@m, \@i);
 }
 
